import type * as React from 'react';
import type { ComponentToken as AlertComponentToken } from '../alert/style';
import type { ComponentToken as AnchorComponentToken } from '../anchor/style';
import type { ComponentToken as AvatarComponentToken } from '../avatar/style';
import type { ComponentToken as BackTopComponentToken } from '../back-top/style';
import type { ComponentToken as ButtonComponentToken } from '../button/style';
import type { ComponentToken as CalendarComponentToken } from '../calendar/style';
import type { ComponentToken as CarouselComponentToken } from '../carousel/style';
import type { ComponentToken as CascaderComponentToken } from '../cascader/style';
import type { ComponentToken as CheckboxComponentToken } from '../checkbox/style';
import type { ComponentToken as DatePickerComponentToken } from '../date-picker/style';
import type { ComponentToken as DividerComponentToken } from '../divider/style';
import type { ComponentToken as DropdownComponentToken } from '../dropdown/style';
import type { ComponentToken as EmptyComponentToken } from '../empty/style';
import type { ComponentToken as ImageComponentToken } from '../image/style';
import type { ComponentToken as InputNumberComponentToken } from '../input-number/style';
import type { ComponentToken as LayoutComponentToken } from '../layout/style';
import type { ComponentToken as ListComponentToken } from '../list/style';
import type { ComponentToken as MentionsComponentToken } from '../mentions/style';
import type { ComponentToken as MenuComponentToken } from '../menu/style';
import type { ComponentToken as MessageComponentToken } from '../message/style';
import type { ComponentToken as ModalComponentToken } from '../modal/style';
import type { ComponentToken as NotificationComponentToken } from '../notification/style';
import type { ComponentToken as PopconfirmComponentToken } from '../popconfirm/style';
import type { ComponentToken as PopoverComponentToken } from '../popover/style';
import type { ComponentToken as ProgressComponentToken } from '../progress/style';
import type { ComponentToken as RadioComponentToken } from '../radio/style';
import type { ComponentToken as RateComponentToken } from '../rate/style';
import type { ComponentToken as ResultComponentToken } from '../result/style';
import type { ComponentToken as SegmentedComponentToken } from '../segmented/style';
import type { ComponentToken as SelectComponentToken } from '../select/style';
import type { ComponentToken as SkeletonComponentToken } from '../skeleton/style';
import type { ComponentToken as SliderComponentToken } from '../slider/style';
import type { ComponentToken as SpaceComponentToken } from '../space/style';
import type { ComponentToken as SpinComponentToken } from '../spin/style';
import type { ComponentToken as StepsComponentToken } from '../steps/style';
import type { ComponentToken as TableComponentToken } from '../table/style';
import type { ComponentToken as TabsComponentToken } from '../tabs/style';
import type { ComponentToken as TimelineComponentToken } from '../timeline/style';
import type { ComponentToken as TooltipComponentToken } from '../tooltip/style';
import type { ComponentToken as TransferComponentToken } from '../transfer/style';
import type { ComponentToken as TypographyComponentToken } from '../typography/style';
import type { ComponentToken as UploadComponentToken } from '../upload/style';
export declare const PresetColors: readonly ["blue", "purple", "cyan", "green", "magenta", "pink", "red", "orange", "yellow", "volcano", "geekblue", "lime", "gold"];
declare type PresetColorKey = typeof PresetColors[number];
export declare type PresetColorType = Record<PresetColorKey, string>;
declare type ColorPaletteKeyIndex = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10;
export declare type ColorPalettes = {
    [key in `${keyof PresetColorType}-${ColorPaletteKeyIndex}`]: string;
};
export interface ComponentTokenMap {
    Affix?: {};
    Alert?: AlertComponentToken;
    Anchor?: AnchorComponentToken;
    Avatar?: AvatarComponentToken;
    BackTop?: BackTopComponentToken;
    Badge?: {};
    Button?: ButtonComponentToken;
    Breadcrumb?: {};
    Carousel?: CarouselComponentToken;
    Cascader?: CascaderComponentToken;
    Checkbox?: CheckboxComponentToken;
    Collapse?: {};
    DatePicker?: DatePickerComponentToken;
    Descriptions?: {};
    Divider?: DividerComponentToken;
    Drawer?: {};
    Dropdown?: DropdownComponentToken;
    Empty?: EmptyComponentToken;
    Form?: {};
    Grid?: {};
    Image?: ImageComponentToken;
    Input?: {};
    InputNumber?: InputNumberComponentToken;
    Layout?: LayoutComponentToken;
    List?: ListComponentToken;
    Mentions?: MentionsComponentToken;
    Notification?: NotificationComponentToken;
    Pagination?: {};
    Popover?: PopoverComponentToken;
    Popconfirm?: PopconfirmComponentToken;
    Rate?: RateComponentToken;
    Radio?: RadioComponentToken;
    Result?: ResultComponentToken;
    Segmented?: SegmentedComponentToken;
    Select?: SelectComponentToken;
    Skeleton?: SkeletonComponentToken;
    Slider?: SliderComponentToken;
    Spin?: SpinComponentToken;
    Statistic?: {};
    Switch?: {};
    Tag?: {};
    Tree?: {};
    TreeSelect?: {};
    Typography?: TypographyComponentToken;
    Timeline?: TimelineComponentToken;
    Transfer?: TransferComponentToken;
    Tabs?: TabsComponentToken;
    Calendar?: CalendarComponentToken;
    Card?: {};
    Steps?: StepsComponentToken;
    Menu?: MenuComponentToken;
    Modal?: ModalComponentToken;
    Message?: MessageComponentToken;
    Upload?: UploadComponentToken;
    Tooltip?: TooltipComponentToken;
    Table?: TableComponentToken;
    Space?: SpaceComponentToken;
    Progress?: ProgressComponentToken;
}
declare type OverrideComponentToken = {
    [key in keyof ComponentTokenMap]: Partial<ComponentTokenMap[key]>;
};
export interface OverrideToken extends OverrideComponentToken {
    derivative?: Partial<MapToken>;
    /** @private Internal Usage */
    alias?: Partial<AliasToken>;
}
/** Final token which contains the components level override */
export declare type GlobalToken = AliasToken & ComponentTokenMap;
export interface SeedToken extends PresetColorType {
    colorPrimary: string;
    colorSuccess: string;
    colorWarning: string;
    colorError: string;
    colorInfo: string;
    colorTextBase: string;
    colorTextLightSolid: string;
    /** Base component background color. Will derivative container background color with this */
    colorBgBase: string;
    fontFamily: string;
    fontSizeBase: number;
    gridUnit: number;
    gridBaseStep: number;
    /** Border width of base components */
    lineWidth: number;
    lineType: string;
    motionUnit: number;
    motionBase: number;
    motionEaseOutCirc: string;
    motionEaseInOutCirc: string;
    motionEaseInOut: string;
    motionEaseOutBack: string;
    motionEaseInQuint: string;
    motionEaseOutQuint: string;
    motionEaseOut: string;
    radiusBase: number;
    sizeUnit: number;
    sizeBaseStep: number;
    sizePopupArrow: number;
    controlHeight: number;
    /** Base zIndex of component like BackTop, Affix which can be cover by large popup */
    zIndexBase: number;
    /** Base popup component zIndex */
    zIndexPopupBase: number;
    /** Define default Image opacity. Useful when in dark-like theme */
    opacityImage: number;
}
export interface ColorMapToken {
    colorPrimaryHover: string;
    colorPrimaryBg: string;
    colorPrimaryBgHover: string;
    colorPrimaryActive: string;
    colorPrimaryBorder: string;
    colorPrimaryBorderHover: string;
    colorSuccessBorder: string;
    colorSuccessBg: string;
    colorWarningHover: string;
    colorWarningActive: string;
    colorWarningBorder: string;
    colorWarningBg: string;
    colorErrorHover: string;
    colorErrorActive: string;
    colorErrorBorder: string;
    colorErrorBg: string;
    colorInfoBorder: string;
    colorInfoBg: string;
    /** Color of layout background */
    colorBgLayout: string;
    colorBgContent: string;
    /** Color of popup background */
    colorBgElevated: string;
    /** Color of component background */
    colorBgContainer: string;
    colorBgContentHover: string;
    colorBgContainerSecondary: string;
    colorBgContainerDisabled: string;
    colorBorder: string;
    colorBorderBg: string;
    colorBorderSecondary: string;
    colorSplit: string;
    colorText: string;
    colorTextSecondary: string;
    colorTextDisabled: string;
    colorTextHeading: string;
    colorTextLabel: string;
    /** Weak action. Such as `allowClear` or Alert close button */
    colorAction: string;
    /** Weak action hover color. Such as `allowClear` or Alert close button */
    colorActionHover: string;
    colorLink: string;
    colorLinkHover: string;
    colorLinkActive: string;
    colorBgMask: string;
    colorBgItemHover: string;
    colorBgFillTmp: string;
    colorBgTooltipTmp: string;
    buttonColorBgTextHover: string;
    buttonColorBgTextActive: string;
    segmentedBgColor: string;
    segmentedBgColorHover: string;
    segmentedBgColorActive: string;
}
export interface CommonMapToken {
    fontSizes: number[];
    lineHeights: number[];
    sizeSpace: number;
    sizeSpaceXS: number;
    sizeSpaceXXS: number;
    sizeSpaceSM: number;
    gridSpaceSM: number;
    gridSpaceBase: number;
    gridSpaceLG: number;
    gridSpaceXL: number;
    gridSpaceXXL: number;
    lineWidthBold: number;
    motionDurationFast: string;
    motionDurationMid: string;
    motionDurationSlow: string;
    radiusSM: number;
    radiusLG: number;
    radiusXL: number;
    /** @private Only Used for control inside component like Multiple Select inner selection item */
    controlHeightXS: number;
    controlHeightSM: number;
    controlHeightLG: number;
}
export interface MapToken extends SeedToken, ColorPalettes, ColorMapToken, CommonMapToken {
    colorPrimaryOutline: string;
    colorWarningOutline: string;
    colorErrorOutline: string;
}
export interface AliasToken extends MapToken {
    /** Placeholder text color */
    colorTextPlaceholder: string;
    colorHighlight: string;
    fontSizeSM: number;
    fontSize: number;
    fontSizeLG: number;
    fontSizeXL: number;
    /** Operation icon in Select, Cascader, etc. icon fontSize. Normal is same as fontSizeSM */
    fontSizeIcon: number;
    fontSizeHeading1: number;
    fontSizeHeading2: number;
    fontSizeHeading3: number;
    fontSizeHeading4: number;
    fontSizeHeading5: number;
    /** For heading like h1, h2, h3 or option selected item */
    fontWeightStrong: number;
    lineHeight: number;
    lineHeightLG: number;
    lineHeightSM: number;
    lineHeightHeading1: number;
    lineHeightHeading2: number;
    lineHeightHeading3: number;
    lineHeightHeading4: number;
    lineHeightHeading5: number;
    controlLineWidth: number;
    controlLineType: string;
    controlRadius: number;
    controlOutlineWidth: number;
    controlItemBgHover: string;
    controlItemBgActive: string;
    controlItemBgActiveHover: string;
    controlInteractiveSize: number;
    controlItemBgActiveDisabled: string;
    opacityLoading: number;
    padding: number;
    margin: number;
    boxShadow: string;
    linkDecoration: React.CSSProperties['textDecoration'];
    linkHoverDecoration: React.CSSProperties['textDecoration'];
    linkFocusDecoration: React.CSSProperties['textDecoration'];
    controlPaddingHorizontal: number;
    controlPaddingHorizontalSM: number;
    paddingSM: number;
    paddingXS: number;
    paddingXXS: number;
    paddingLG: number;
    paddingXL: number;
    marginXXS: number;
    marginXS: number;
    marginSM: number;
    marginLG: number;
    marginXL: number;
    marginXXL: number;
    screenXS: number;
    screenXSMin: number;
    screenXSMax: number;
    screenSM: number;
    screenSMMin: number;
    screenSMMax: number;
    screenMD: number;
    screenMDMin: number;
    screenMDMax: number;
    screenLG: number;
    screenLGMin: number;
    screenLGMax: number;
    screenXL: number;
    screenXLMin: number;
    screenXLMax: number;
    screenXXL: number;
    screenXXLMin: number;
    screenXXLMax: number;
    /** Used for DefaultButton, Switch which has default outline */
    controlTmpOutline: string;
    boxShadowPopoverArrow: string;
    boxShadowPopoverArrowBottom: string;
    boxShadowSegmentedSelectedItem: string;
    boxShadowCard: string;
    boxShadowDrawerRight: string;
    boxShadowDrawerLeft: string;
    boxShadowDrawerUp: string;
    boxShadowDrawerDown: string;
    boxShadowTabsOverflowLeft: string;
    boxShadowTabsOverflowRight: string;
    boxShadowTabsOverflowTop: string;
    boxShadowTabsOverflowBottom: string;
}
export {};
